@@ -94,7 +94,7 @@ class Base(ABC):
 
         # En caso de que se indique con otro nombre
         if AUTH is None:
-            AUTH = HEADERS.get("Authorization", None)
+            AUTH = HEADERS.get("Authorization", "")
 
         # Seleccion de parametros
         for i in paramList:
