@@ -4,6 +4,7 @@ import uuid
 import copy
 import json
 import time
+import _thread
 from waitress import serve
 from bottle import Bottle, request, HTTPResponse
 from .Util import getItemBy
@@ -85,7 +86,7 @@ class HttpTransit:
         Key_op, meta = self.__create_meta(id)
 
         # Lanzar el metodo
-        self._message(meta)
+        _thread.start_new_thread(self._message, (meta,))
 
         # Error
         IS_ERROR = False
