@@ -30,6 +30,7 @@ class Worker(Base):
             return self.formatResponse(
                 request,
                 # Generar formato
-                HttpResponse(None, err.http_code, headers=err.headers),
+                HttpResponse(None, err.http_code,
+                             headers=err.headers, message=err.message),
                 err.errorCode
             )
