@@ -593,9 +593,9 @@ class Microservices(BaseClass, ABC):
         if rootSpan is not None:
             rootSpan = self.___Tracer.extract(Format.TEXT_MAP, rootSpan)
 
-        if rootSpan is None:
+        if mth is None:
             span = self.___Tracer.start_span(
-                operation_name=getattr(mth, '__FUNC_NAME__'))
+                operation_name='No identificado')
         else:
             span = self.___Tracer.start_span(operation_name=getattr(
                 mth, '__FUNC_NAME__'), references=child_of(rootSpan))
